==> granule_1.2.0.orig.tar.gz: granule-1.2.0.orig/src/CardViewHelpDialog.h <==
// -*- c++ -*-
//------------------------------------------------------------------------------
//                         CardViewHelpDialog.h
//------------------------------------------------------------------------------
// $Id: CardViewHelpDialog.h,v 1.3 2005/06/11 04:42:43 vlg Exp $
//
//  Copyright (c) 2005 by Vladislav Grinchenko
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//
//  Date: Jun 8, 2005
//------------------------------------------------------------------------------

#ifndef CARD_VIEW_HELP_DIALOG_H
#define CARD_VIEW_HELP_DIALOG_H

#include <gtkmm/dialog.h>
#include <gtkmm/button.h>
#include <gtkmm/textview.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/buttonbox.h>
#include "Granule-main.h"


class CardViewHelpDialog : public Gtk::Window
{  
public:
	CardViewHelpDialog (Gtk::Window& parent_);

private:
	void create_tags (Glib::RefPtr<Gtk::TextBuffer>& ref_buffer_);
	void insert_text (Glib::RefPtr<Gtk::TextBuffer>& ref_buffer_);

	void on_close_clicked () { hide (); }
	virtual bool on_delete_event(GdkEventAny* any_)	{
		hide ();
		return false;
	}

private:
	Gtk::Window*          m_dialog;
	Gtk::VBox             m_vbox;

	Gtk::Button*          m_close_button;
	Gtk::TextView*        m_textview;
	Gtk::ScrolledWindow*  m_scrolledwindow;
};

#endif

==> granule_1.2.3.orig.tar.gz: granule-1.2.3.orig/src/CardViewHelpDialog.h <==
// -*- c++ -*-
//------------------------------------------------------------------------------
//                         CardViewHelpDialog.h
//------------------------------------------------------------------------------
// $Id: CardViewHelpDialog.h,v 1.5 2006/02/13 03:50:25 vlg Exp $
//
//  Copyright (c) 2005 by Vladislav Grinchenko
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//
//  Date: Jun 8, 2005
//------------------------------------------------------------------------------

#ifndef CARD_VIEW_HELP_DIALOG_H
#define CARD_VIEW_HELP_DIALOG_H

#include <gtkmm/dialog.h>
#include <gtkmm/button.h>
#include <gtkmm/textview.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/buttonbox.h>
#include "Granule-main.h"


#ifdef IS_HILDON
#    include <hildon-widgetsmm/appview.h>
#endif

class CardViewHelpDialog : public Gtk::Window
{  
public:
#ifdef IS_HILDON
	CardViewHelpDialog (Hildon::AppView& parent_);
#else
	CardViewHelpDialog (Gtk::Window& parent_);
#endif

private:
	void create_tags (Glib::RefPtr<Gtk::TextBuffer>& ref_buffer_);
	void insert_text (Glib::RefPtr<Gtk::TextBuffer>& ref_buffer_);

	void on_close_clicked () { hide (); }
	virtual bool on_delete_event(GdkEventAny* any_)	{
		hide ();
		return false;
	}

private:
	Gtk::Window*          m_dialog;
	Gtk::VBox             m_vbox;

	Gtk::Button*          m_close_button;
	Gtk::TextView*        m_textview;
	Gtk::ScrolledWindow*  m_scrolledwindow;
};

#endif
